================
``xeofs.multi``
================
Methods that investigate relationships or patterns between variables across **more than two** distinct datasets.

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   ~xeofs.multi.CCA

------------------------------
Sparse Solutions via Rotation
------------------------------

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

